Welcome to thnkrAI’s Pricing Model and SDK documentation.

thnkrAI allows you to conduct detailed pricing analysis on any kind of product or product datasets you want in an easy and accessible way. thnkrAI’s pricing model can bring enabling price predictions, discovery, and insights to your data.

Use the thnkrAI SDK to quickly read product information and predict prices using the model’s price prediction endpoint.